Index: Source/platform/heap/ThreadState.h |
diff --git a/Source/platform/heap/ThreadState.h b/Source/platform/heap/ThreadState.h |
index 0ff7243bf3bac5dce6282c018f24d7357f064d55..39df3f485979993816852eca748a5531967f905e 100644 |
--- a/Source/platform/heap/ThreadState.h |
+++ b/Source/platform/heap/ThreadState.h |
@@ -242,8 +242,11 @@ public: |
static void attachMainThread(); |
static void detachMainThread(); |
- // Trace all GC roots, called when marking the managed heap objects. |
- static void visitRoots(Visitor*); |
+ // Trace all persistent roots, called when marking the managed heap objects. |
+ static void visitPersistentRoots(Visitor*); |
+ |
+ // Trace all objects found on the stack, used when doing conservative GCs. |
+ static void visitStackRoots(Visitor*); |
// Associate ThreadState object with the current thread. After this |
// call thread can start using the garbage collected heap infrastructure. |
@@ -509,7 +512,6 @@ public: |
HeapStats& statsAfterLastGC() { return m_statsAfterLastGC; } |
void setupHeapsForTermination(); |
- void visitLocalRoots(Visitor*); |
private: |
explicit ThreadState(); |
@@ -562,8 +564,6 @@ private: |
// and lazily construct ThreadState in it using placement new. |
static uint8_t s_mainThreadStateStorage[]; |
- void trace(Visitor*); |
- |
ThreadIdentifier m_thread; |
OwnPtr<PersistentNode> m_persistents; |
StackState m_stackState; |